@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 """
 ===============================================================
@@ -19,7 +20,10 @@ from ScriboExc import WarningExc
 from Structure import Structure
 from Message import Message, POST, INBOX, OUTBOX
 from SqlDriver import sql_driver, SQL_ACCOUNT_FIELDS
+#from abc import *
 
+SORT_DESC_DATE = " ORDER BY date DESC"
+SORT_ASC_DATE = " ORDER BY date ASC"
 
 
 class Account(Structure):
@@ -34,7 +38,7 @@ class Account(Structure):
     @date 2009/13/08 
     """
 
-    def __new__(cls, id=None):
+    def __new__(cls, id):
         """
         Account is base class for objects with secvices API. 
         We must choose object type before memory allocation.
@@ -59,11 +63,46 @@ class Account(Structure):
         """
 
         super(Account, self).__init__("Accounts", id)
-        if not id:
-            self.group = False
-            self.friends = []
-            self.readers = []
-            self.journals = []
+
+
+    @staticmethod
+    def register(service, username):
+        """
+        Register new account in DB. If there is another account with this 
+        username and service, that account will be return. Otherwise new record 
+        will be created and initialized.
+        
+        @param service (child of Account) - service type of account
+        @param username (string) - username of account
+        @return (type of service param) instance of account of given service 
+                with given username  
+        """
+
+        acc = Account.find(service, username)
+
+        if not acc:
+            tmp = Structure("Accounts")
+            tmp._set_field("service_id", service.__name__)
+            acc = Account(tmp.id)
+            acc._set_username(username)
+            acc.reset()
+
+        return acc
+
+
+    def reset(self):
+        """
+        Reset date in account(not all! this unfinished function)
+        
+        @return None
+        """
+        self.group = False
+        self.friends_list = []
+        self.readers = []
+        self.journals = []
+
+        self.del_posts()
+
 
 
     """
@@ -161,7 +200,7 @@ class Account(Structure):
         return bool(self._get_field("is_group"))
 
 
-    def get_friends(self):
+    def get_friends_list(self):
         """
         Get field from Accounts table.
 
@@ -189,7 +228,7 @@ class Account(Structure):
 
 
     def get_posts(self):
-        query = "journal='%s' AND type=%d" % (self.id, POST)
+        query = "journal='%s' AND type=%d" % (self.id, POST)+SORT_DESC_DATE
         posts = Message.find(fetch_one=False, where=query)
         return posts
 
@@ -212,7 +251,7 @@ class Account(Structure):
     ===============================================================
     """
 
-    def set_service_id(self, value):
+    def _set_service_id(self, value):
         """
         Change field value in Accounts table.
 
@@ -221,7 +260,7 @@ class Account(Structure):
         """
         self._set_field("service_id", value)
 
-    def set_username(self, value):
+    def _set_username(self, value):
         """
         Change field value in Accounts table.
 
@@ -326,11 +365,11 @@ class Account(Structure):
             raise WarningExc("Account setter", "readers value should be list")
         self._set_field("readers", repr(value))
 
-    def set_friends(self, value):
+    def set_friends_list(self, value):
         """
         Change field value in Messages table.
         
-        @param value (string) friends 
+        @param value (string) friends ids
         @return None
         """
         if type(value) != list:
@@ -357,9 +396,9 @@ class Account(Structure):
     """
 
     ## property
-    service_id = property(get_service_id, set_service_id)
+    service_id = property(get_service_id)
     ## property
-    username = property(get_username, set_username)
+    username = property(get_username)
     ## property
     passwd = property(get_passwd, set_passwd)
     ## property
@@ -375,7 +414,7 @@ class Account(Structure):
     ## property
     date = property(get_date, set_date)
     ## property
-    friends = property(get_friends, set_friends)
+    friends_list = property(get_friends_list, set_friends_list)
     ## property
     group = property(get_group, set_group)
     ## property
@@ -417,7 +456,7 @@ class Account(Structure):
         msg.read = False
         msg.parent = None
 
-
+    
     def del_account(self):
         """
         Delete account and all his posts and comments from DB
@@ -430,19 +469,26 @@ class Account(Structure):
 
         self.del_posts()
 
-        self._del_struct()
-
+        # FIXME: we cant delete structure because someone else can have this 
+        # account as a friend 
+        #self._del_struct()
+        self.prof = None
+    
     def del_posts(self):
         """
         Delete all posts from some journal
         
         @return None
         """
+        # FIXME: we cant delete posts because someone else can have this 
+        # account as a friend
+        '''
         query = 'SELECT id FROM Messages WHERE journal=? AND type=?'
         id_list = sql_driver.select_mcmd(query, (self._id, POST))
 
         for i in id_list:
             Message(i[0]).del_msg_tree()
+        '''
 
 
     def set_default(self):
@@ -482,9 +528,9 @@ class Account(Structure):
         @return (bool) True if account was successfully added, False otherwise 
         """
 
-        list = self.friends
+        list = self.friends_list
         list.append(user.id)
-        self.friends = list
+        self.friends_list = list
         return True
 
 
@@ -498,13 +544,13 @@ class Account(Structure):
         @return (bool) True if account was successfully removed, False otherwise        
         """
 
-        list = self.friends
+        list = self.friends_list
         try:
             list.remove(user.id)
         except ValueError:
             return False
 
-        self.friends = list
+        self.friends_list = list
         return True
 
 
@@ -596,3 +642,72 @@ class Account(Structure):
             accounts.append(Account(i))
 
         return accounts
+
+
+    def get_friends(self):
+
+        list = self.friends_list
+        accounts = []
+
+        for i in list:
+            accounts.append(Account(i))
+
+        return accounts
+    """
+    ===============================================================
+        Comments support
+    ===============================================================
+    """
+    #abstractmethod
+    def send_comment (self, msg, parent, addit):
+    	"""
+	send comment to service 
+	
+	@param msg (Message) message for sending
+	@param parent (Message) parent message
+	@param addit (Dict) Additional data
+	@return None
+	"""
+	pass
+    #abstractmethod
+    def del_comment (self, msg, addit):
+	"""
+	delete comment from service
+	
+	@param msg (Message) message for deleting
+	@param addit (Dict) Additional data
+	@return None
+	"""
+	pass
+    
+    #abstractmethod
+    def freeze_comment (self, msg, addit):
+      	"""
+	freeze/unfreeze comment
+	
+	@param msg (Message) message for freezing
+	@param addit (Dict) Additional data
+	@return None
+	"""
+	pass 
+    
+    #abstractmethod 
+    def screen_comment (self, msg, addit):
+	"""
+	screen/unscreen comment
+	
+	@param msg (Message) message for screening
+	@param addit (Dict) Additional data
+	@return None
+	"""
+	pass 
+    
+    #abstractmethod 
+    def refresh_comments (self, addit):
+	"""
+	Sync comments with service
+	
+	@param addit (Dict) Additional data
+	@return None
+	"""
+	pass 
\ No newline at end of file
