@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 """
 ===============================================================
@@ -18,8 +19,6 @@ from ScriboExc import WarningExc
 from Structure import Structure
 from SqlDriver import sql_driver, SQL_MESSAGE_FIELDS
 
-
-
 """
 ===============================================================
     States for type-field in database (table Messages)
@@ -31,6 +30,15 @@ POST = 2     # read
 COMMENT = 3  # comment
 INBOX = 4
 OUTBOX = 5
+POSTER_F = "poster"
+TEXT_F =  "text"
+READ_F =  "read"
+SERVICE_F = "service"
+DATE_F = "date"
+SORT_DESC_DATE = " ORDER BY date DESC"
+
+
+
 
 class Message(Structure):
 
@@ -208,7 +216,7 @@ class Message(Structure):
         
         @return (list) list of Messages with comments to this message
         """
-        query = 'SELECT id FROM Messages WHERE parent=?'
+        query = 'SELECT id FROM Messages WHERE parent=? ORDER BY date'
         id_list = sql_driver.select_mcmd(query, (self.id,))
 
         comments = []
@@ -543,3 +551,150 @@ class Message(Structure):
             return False
 
         return True
+ 
+    @staticmethod
+    def filter_msg(field, first_value = None, second_value = None, already_found = None, poster = None):
+        list_post_filters = []
+        cur_list = []
+        if poster:
+           whr = 'journal='+str(poster)+' and '
+        else:
+           whr = ''
+
+        if already_found:
+            whr +='('
+            for i in xrange(0,len(already_found)-1):
+                whr += 'id='+ str(already_found[i].id) + ' or '
+            whr += 'id='+ str(already_found[-1].id) + ') and '
+
+
+        if field == POSTER_F:
+            if first_value:
+                whr += 'poster='+str(first_value)+SORT_DESC_DATE
+                cur_list = Message.find(fetch_one = False, where = whr)
+                if cur_list:
+                    list_post_filters.extend(cur_list)
+        elif field == TEXT_F:
+            if first_value:
+                first_value = unicode(first_value).lstrip().rstrip().replace(" ","%")
+                whr += '(text like \'%'+first_value+'%\' or tags like \'%'+\
+                      first_value+'%\' or title like \'%'+first_value+'%\')'+SORT_DESC_DATE
+                cur_list = Message.find(fetch_one = False, where = whr)
+                if cur_list:
+                    list_post_filters.extend(cur_list)
+        elif field == READ_F:
+            if first_value:
+                whr += 'read='+str(first_value)+SORT_DESC_DATE
+                cur_list = Message.find(fetch_one = False, where = whr)
+                if cur_list:
+                    list_post_filters.extend(cur_list)          
+        elif field == SERVICE_F:
+             if first_value:
+                subwhr = '(SELECT id FROM Accounts WHERE service_id='+first_value+' and prof ='+ str(1)+')'
+                whr += 'poster='+ subwhr+SORT_DESC_DATE
+                cur_list = Message.find(fetch_one = False, where = whr)
+                if cur_list:
+                    list_post_filters.extend(cur_list) 
+        elif field == DATE_F:
+            if first_value and second_value:
+                whr += '(date >=\''+str(first_value)+'\' and date <=\''+str(second_value)+'\')'+SORT_DESC_DATE
+                cur_list = Message.find(fetch_one = False, where = whr)
+                if cur_list:
+                    list_post_filters.extend(cur_list)                   
+            elif first_value:
+                whr += 'date >=\''+str(first_value)+'\''+SORT_DESC_DATE
+                cur_list = Message.find(fetch_one = False, where = whr)
+                if cur_list:
+                    list_post_filters.extend(cur_list)       
+            elif second_value:
+                whr += 'date <=\''+str(second_value)+'\''+SORT_DESC_DATE
+                cur_list = Message.find(fetch_one = False, where = whr)
+                if cur_list:
+                    list_post_filters.extend(cur_list)  
+        return list_post_filters     
+        
+    @staticmethod
+    def sort_msg(value, sort, already_found, poster = None):
+        list_sort_msg = []
+        whr = ""
+    
+        if already_found:
+            whr +='('
+            for i in xrange(0,len(already_found)-1):
+                whr += 'id='+ str(already_found[i].id) + ' or '
+            whr += 'id='+ str(already_found[-1].id) + ')'
+        
+        if poster:
+            if already_found:
+                whr += ' and '
+            whr += '('
+            for i in xrange(0,len(poster)-1):
+                whr += 'journal='+str(poster[i])+' or '
+            whr += 'journal='+str(poster[-1])+')'
+
+        whr +=' ORDER BY '+value+" "+ sort
+        print whr
+        list_sort_msg = Message.find(fetch_one = False, where = whr)
+
+        return list_sort_msg
+
+
+        
+    """
+    ===============================================================
+        Comments support
+    ===============================================================
+    """
+
+    def is_deleted(self):
+      	"""
+	Check comment for deleting
+	
+	@return True if comment is marked for deletind or False otherwise
+	"""
+	
+	if COMMENT <> self.type:
+	    raise TypeError("Illegal message type", "Message is not comment")
+	  
+	sm=self.misc
+	return sm['deleted']
+	    
+
+    def has_undeleted_childes(self):
+      	"""
+	Look for undeleted childes
+	
+	@return True if comment have undeleted childes or False otherwise
+	"""
+	if COMMENT <> self.type:
+	    raise TypeError("Illegal message type", "Message is not comment")
+	  
+	comm = self.get_comments()
+	for i in comm:
+	    if not i.is_deleted():
+		return True
+	    if i.has_undeleted_childes():
+		return True
+	return False
+	
+	
+    def del_comment_local(self):
+      	"""
+	Delete comment sub-tree localy
+	
+	@return None
+	"""
+	if COMMENT <> self.type:
+	    raise TypeError("Illegal message type", "Message is not comment")
+	  
+	tmp = self.misc
+	tmp['deleted'] = True
+	self.misc = tmp
+	if self.has_undeleted_childes():
+	    self.text = '(Deleted Comment)'
+	    self.title = ''
+	else:
+	    par = self.parent
+	    self.del_msg_tree()
+	    if par.is_deleted():
+		par.del_comment_local()
