@@ -1,4 +1,5 @@
 #!/usr/bin/env python
+# -*- coding: utf-8 -*-
 
 """
 ===============================================================
@@ -15,17 +16,20 @@ __license__ = "GPLv2"
 
 import xmlrpclib
 import urllib2
+from urllib import urlencode
 import os
 import time
 import hashlib
 import socket
 
-from ldm.Message import Message
+from ldm.Message import Message, POST, COMMENT
 from ldm.Account import Account
-from ldm.SqlDriver import TIME_FORMAT
+from ldm.SqlDriver import TIME_FORMAT, sql_driver
 from ProxyedTransp import ProxyedTransp
 from Service import Service
 from ScriboExc import XmlrpcExc, SocketExc, WarningExc
+from LjCommentUtils import *
+
 
 MAX_EVENTS = 50
 MAX_SKIP = 100
@@ -34,7 +38,7 @@ ONE_PAGE = 20
 
 LJ_SERVER = "http://www.livejournal.com/interface/xmlrpc:80"
 LJ_USERPICS = 'http://l-userpic.livejournal.com/'
-
+LJ_SHORT = "http://www.livejournal.com/"
 
 class LivejAccount(Account, Service):
     """
@@ -204,7 +208,6 @@ class LivejAccount(Account, Service):
                      })
 
         req = 'self._server.LJ.XMLRPC.' + funct + '(' + repr(param) + ')'
-
         try:
             res = eval(req)
         except xmlrpclib.Fault, exc:
@@ -854,6 +857,289 @@ class LivejAccount(Account, Service):
 
         return filename
 
+    """
+    ===============================================================
+    Support of comment
+    ===============================================================
+    """
+
+    def get_session (self):
+	"""
+	Generate session for using cookie autentification
+	
+	@return Cookie string
+	"""
+	self.connect()
+        params = {
+            'username': self.username,
+            'ver': 1,
+            'password': self.passwd,
+            }
+        lj_sess = self._server.LJ.XMLRPC.sessiongenerate(params)
+        
+        return lj_sess['ljsession']
+
+    def send_comment (self, msg, parent, addit = None):
+	"""
+	send comment to livejournal
+	
+	@param msg (Message) message for sending
+	@param parent (Message) parent message
+	@param addit (Dict) unused
+	@return None
+	"""
+	misc = parent.misc
+	if parent.type == POST:
+	    ptid = 0
+	else:
+	    ptid = misc['parenttalkid']
+        req = {
+            'parenttalkid': ptid,
+            'itemid': parent.custom_id,
+            'journal': parent.journal.username,
+            'usertype': 'user',
+            'userpost': self.username,
+            'password': self.passwd,
+            'do_login': '1',
+            'subject': msg.title,
+            'subjection':'none',
+            'body':msg.text,
+        }
+        req = urlencode(req)
+        print req
+        try:
+	    resp = urllib2.urlopen(urllib2.Request(LJ_SHORT+"/talkpost_do.bml",req))
+	    tmp = resp.readline()
+	    resp.close()
+	    #f=open('res.html','wt')
+	    #f.write(tmp)
+	    #f.close()
+        except IOError, exc:
+            raise SocketExc(self, exc)
+
+
+    def del_comment (self, msg, addit = None):
+	"""
+	delete comment from livejournal
+	
+	@param msg (Message) message for deleting
+	@param addit (Dict) must have 'delauthor' and 'delthread' keys only
+	  'delthread' - delete thread flag 1-yes, 0-no (default 0)
+	  'delauthor' - delete all by author flag 1-yes, 0-no (default 0) now unused
+	@return None
+	"""
+	##FIXME: deleting by author is not supported yet
+        session = self.get_session()
+        req = urllib2.Request(LJ_SHORT+"/delcomment.bml?journal=%s&id=%i" % (msg.journal,\
+             msg.custom_id),headers={'Cookie': "ljsession=%s" %(session)})
+        r = urllib2.urlopen(req)
+        page = r.readlines()
+        self.__confirm(page,session,{'delauthor':0,'delthread':addit['delthread']})
+        ##FIXME: add removing from DB!!!
+        
+    def freeze_comment (self, msg, addit = None):
+	"""
+	freeze/unfreeze comment from livejournal
+	
+	@param msg (Message) message for freezing
+	@param addit (Dict) unused
+	@return None
+	"""
+        session = self.get_session()
+        misc = msg.misc
+        if misc['frozen']:
+            mode = 'freeze'
+        else:
+            mode = 'unfreeze'
+
+        req=urllib2.Request(LJ_SHORT+"/talkscreen.bml?mode=%s&journal=%s&talkid=%i" % (mode, msg.journal,\
+                    msg.custom_id),headers = {'Cookie': "ljsession=%s" %(session)})
+        r = urllib2.urlopen(req)
+        page = r.readlines()
+        self.__confirm(page,session,None)
+        ##FIXME: add marking of frozen to misc
+        ##NOTE: Fix frozen flag when get comments
+        
+    def screen_comment (self, msg, addit = None):
+        """
+	screen/unscreen comment from livejournal
+	
+	@param msg (Message) message for screening
+	@param addit (Dict) unused
+	@return None
+	"""
+        session = self.get_session()
+        misc = msg.misc
+        if misc['screened']:
+            mode = 'screen'
+        else:
+            mode = 'unscreen'
+
+        req=urllib2.Request(LJ_SHORT+"/talkscreen.bml?mode=%s&journal=%s&talkid=%i" % (mode, msg.journal,\
+                    msg.custom_id),headers = {'Cookie': "ljsession=%s" %(session)})
+        r = urllib2.urlopen(req)
+        page = r.readlines()
+        self.__confirm(page,session,None)
+
+
+    def refresh_comments (self, addit = None):
+        """
+	update comments from livejournal
+	
+	@param addit (Dict) unused
+	@return None
+	"""
+        cp = CommentProcessor()
+        acc_misc = self.misc
+        if acc_misc <> None and 'max_getted_comment' in acc_misc:
+	    cp.maxid = acc_misc['acc_misc']
+	    cp.current = acc_misc['acc_misc']-1
+        session = self.get_session()
+        
+        try:
+	    cp.current = acc_misc['acc_misc']
+	except:
+	    cp.current = -1
+	
+	once = True
+        while once or cp.maxid>cp.current:
+	    once = False
+            req = urllib2.Request(LJ_SHORT+"/export_comments.bml?get=comment_meta&startid=%i"\
+                      %(cp.current+1), headers = {'Cookie': "ljsession=%s"%(session)})
+            rxml = urllib2.urlopen(req).read()
+            cp.feedmeta(rxml)
+        
+        try:
+	    cp.current = acc_misc['acc_misc']
+	except:
+	    cp.current = -1
+	 
+	while cp.maxid>cp.current: 
+            req = urllib2.Request(LJ_SHORT+"/export_comments.bml?get=comment_body&startid=%i"\
+                      % (cp.current+1), headers = {'Cookie': "ljsession=%s"%(session)})
+            rxml = urllib2.urlopen(req).read()
+            cp.feeddata(rxml)
+            
+        acc_misc['acc_misc'] = cp.maxid
+        self.misc = acc_misc
+        self.__savecomments(cp.changeset, cp.umap)
+        
+        
+        
+
+        
+    def __savecomments (self, changeset, umap):
+        """
+	update comments in DB by changeset
+	
+	@param changeset (List of Dict) unused
+	@param umap (List of Dict) unused
+	@return None
+	"""
+        ##FIXME: Needs implementation
+        kl = changeset.keys()
+        kl.sort()
+	for i in kl:
+	    if changeset[i]['state']=='A':
+		comment = Message()
+		comment.custom_id = i
+                comment.type = COMMENT
+		if changeset[i]['subject']==None:
+		    changeset[i]['subject'] = '(No Subject)'
+		comment.title = changeset[i]['subject']
+		comment.date = changeset[i]['date']
+		comment.text = changeset[i]['body']
+		
+		comment.misc = {'parenttalkid':changeset[i]['jitemid'],'frozen':False,'screened':False,
+			      'deleted':False}
+		if self.group:
+		    raise TypeError("Illegal Account type", "Account is group. Me cant get comments for group,"\
+			      "so this is an error")
+		
+		
+		print umap[changeset[i]['posterid']]
+                print self.service_id
+                print sql_driver.select_mcmd("SELECT journal, custom_id FROM Messages")
+                #acc_id = sql_driver.select_cmd("SELECT id FROM Accounts WHERE username=? AND service_id=?",\
+		#  (umap[changeset[i]['posterid']], self.service_id))
+		  
+		poster = Account.register(type(self), umap[changeset[i]['posterid']])
+		comment.poster = poster
+		comment.journal = self
+		#.....
+		par_id = changeset[i]['parentid']
+		if par_id == 0:
+		    par_id = changeset[i]['jitemid']
+                print changeset[i]
+                print par_id
+                print self.id
+		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND journal=?",\
+		  (par_id, self.id))
+		par_msg = Message(mid)
+		
+		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND journal=?",\
+		  (changeset[i]['jitemid'], self.id))
+		jitem_msg = Message(mid)
+		par_msg.add_comment(comment, jitem_msg)
+		
+		
+	    elif changeset[i]['state']=='D':
+		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND type=? AND journal=?",\
+		  (i, COMMENT, self.id))
+		scr_msg = Message(mid)
+		scr_msg.del_comment_local(self)
+		
+	    elif changeset[i]['state']=='F':
+		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND type=? AND journal=?",\
+		  (i, COMMENT, self.id))
+		scr_msg = Message(mid)
+		tmisc = scr_msg.misc
+		tmisc['frozen'] = not tmisc['frozen']
+		scr_msg.misc = tmisc
+		
+	    elif changeset[i]['state']=='S':
+		mid = sql_driver.select_cmd("SELECT id FROM Messages WHERE custom_id=? AND type=? AND journal=?",\
+		  (i, COMMENT, self.id))
+		scr_msg = Message(mid)
+		tmisc = scr_msg.misc
+		tmisc['screened'] = not tmisc['screened']
+		scr_msg.misc = tmisc
+	    else:
+		raise Warning("Illegal XML","Illegal XML recieved from LiveJournal")
+	      
+    def __confirm (self, page, session=None, uparams=None):
+	"""
+	Confirm operation. (get form from HTML-page, fill it and send)
+	
+	@param page (string) HTML-page source
+	@param session (string) Cookie string for auhtentification (Default None)
+	@param uparams (dict) additional params for form (Default None)
+	@return None
+	"""
+      
+        if session:
+            headers = {'Cookie':"ljsession=%s" %(session)}
+        else:
+            headers = None
+	# Finds useful content
+        pat = "<!-- your content here -->"
+        while string.find(lines.pop(0), pat) < 0:
+            pass
+
+        pat = "<!-- /content -->"
+        while string.find(lines.pop(), pat) < 0:
+            pass
+	#Look for form in HTML-page
+        html_data = string.join(lines)
+        parcer = CHTMLParser()
+        parcer.feed(html_data)
+	#Update params by user's params
+        params = parcer.params
+        if uparams:
+            params.update(uparams)
+	#send request
+        req=urllib2.Request(parcer.request, params, headers=headers)
+        r = urllib2.urlopen(req)
 
     """
     ===============================================================
