@@ -22,6 +22,7 @@ import sys
 from ldm.Profile import *
 from test.FakeAccount import *
 from ldm.Message import *
+from ldm.Account import Account
 from ldm.SqlDriver import *
 from ScriboExc import *
 
@@ -38,17 +39,14 @@ class LdmTest(unittest.TestCase):
         @return None
         """
 
-        acc1 = FakeAccount()
-        acc2 = FakeAccount()
-        real = FakeAccount()
+        acc1 = Account.register(FakeAccount, "dqwedq")
+        acc2 = Account.register(FakeAccount, "asaqsdqwedq")
+        real = Account.register(FakeAccount, "sqsqfddqwedq")
 
         real.nick = "Maemo-Blogs"
         acc2.nick = "nick_2"
         acc1.nick = "nick_1"
 
-        real.username = "maemoblogs"
-        acc1.username = "username_1"
-        acc2.username = "username_2"
 
         real.passwd = "maemo100500"
 
