@@ -10,6 +10,7 @@ import unittest
 import sys
 
 from ldm.Profile import Profile
+from ldm.Account import Account
 from test.FakeAccount import FakeAccount
 from ldm.Message import Message
 from ScriboExc import WarningExc
@@ -32,7 +33,7 @@ class ProfileTest(unittest.TestCase):
         test for Profile.add_account()
         add one account
         """
-        acc = FakeAccount()
+        acc = Account.register(FakeAccount, "wddwdw")
         self.prof.add_account(acc)
         self.assertTrue(acc in self.prof.accounts)
 
@@ -44,8 +45,9 @@ class ProfileTest(unittest.TestCase):
         """
         self.assertFalse(self.prof.get_accounts())
 
-        for _ in xrange(5):
-            self.test_add_account()
+        for i in xrange(5):
+            acc = Account.register(FakeAccount, "wddwdw" + str(i))
+            self.prof.add_account(acc)
 
         list = self.prof.get_accounts()
         list2 = self.prof.accounts
@@ -58,7 +60,7 @@ class ProfileTest(unittest.TestCase):
         """
         test for Profile.def_account (get_ and set_)
         """
-        acc = FakeAccount()
+        acc = Account.register(FakeAccount, "wddwdcccw")
 
         self.assertRaises(WarningExc, self.prof.set_def_account, acc)
 
@@ -67,16 +69,6 @@ class ProfileTest(unittest.TestCase):
         self.assertEqual(acc, self.prof.def_account)
 
 
-    def test_del_profile(self):
-        """
-        test for Profile.del_profile()
-        delete profile from DB and try to load it after deleting
-        """
-        id = self.prof.id
-        self.prof.del_profile()
-
-        self.assertRaises(WarningExc, Profile, id)
-
 
     def test_get_posts(self):
         """
