@@ -69,12 +69,13 @@ class AddPostWindow(MainWindow):
         if msg:
             author = msg.poster
             self.start_text = msg.text
-            #update post
-            try:
-                author.refresh_post(msg)
-            except WarningExc, exc:
-                super(AddPostWindow, self).show_warning(exc)
-                return
+            if msg.type == POST:
+                #update post
+                try:
+                    author.refresh_post(msg)
+                except WarningExc, exc:
+                    super(AddPostWindow, self).show_warning(exc)
+                    return
 
             self.text_edit.insertPlainText(msg.text)
             if self.start_text != msg.text:
@@ -133,9 +134,9 @@ class AddPostWindow(MainWindow):
         """
         second_tool_bar = ToolbarWindow(parent=self.centr_widg, right=True)
         second_tool_bar.addWidget(self.pict_act)
-        second_tool_bar.addWidget(self.link_act)
         second_tool_bar.addWidget(self.other_act)
         second_tool_bar.addWidget(self.option_act)
+        second_tool_bar.addWidget(self.save_act)
         return second_tool_bar
 
     def create_actions(self):
@@ -152,14 +153,6 @@ class AddPostWindow(MainWindow):
         self.connect(self.pict_act, QtCore.SIGNAL("clicked()"),
                      self.pict_post)
 
-        self.link_act = QtGui.QToolButton(self.centr_widg)
-        self.link_act.setIcon(QtGui.QIcon(self.tr("../data/en/add_link.png")))
-        self.link_act.setText(self.tr("Add link"))
-        self.link_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
-        self.link_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
-        self.connect(self.link_act, QtCore.SIGNAL("clicked()"),
-                     self.link_post)
-
         self.other_act = QtGui.QToolButton(self.centr_widg)
         self.other_act.setIcon(QtGui.QIcon(self.tr("../data/en/add_html.png")))
         self.other_act.setText(self.tr("HTML"))
@@ -175,6 +168,15 @@ class AddPostWindow(MainWindow):
         self.option_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.connect(self.option_act, QtCore.SIGNAL("clicked()"),
                      self.option_post)
+        
+        self.save_act = QtGui.QToolButton(self.centr_widg)
+        self.save_act.setIcon(QtGui.QIcon(self.tr("../data/en/save.png")))
+        self.save_act.setText(self.tr("Save"))
+        self.save_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
+        self.save_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
+        self.connect(self.save_act, QtCore.SIGNAL("clicked()"),
+                     self.save_post)
+
 
         self.undo_act = QtGui.QToolButton(self.centr_widg)
         self.undo_act.setIcon(QtGui.QIcon(self.tr("../data/en/undo.png")))
@@ -193,7 +195,7 @@ class AddPostWindow(MainWindow):
                      self.text_edit.redo)
     
         self.send_act = QtGui.QToolButton(self)
-        if not self.msg:
+        if not self.msg or not self.msg.poster:
             self.send_act.setIcon(QtGui.QIcon(self.tr("../data/en/post_send_to.png")))
             self.send_act.setText(self.tr("Send to.."))
             self.connect(self.send_act, QtCore.SIGNAL("clicked()"),
@@ -233,13 +235,17 @@ class AddPostWindow(MainWindow):
                                QtGui.QMessageBox.No)
             if (ret == QtGui.QMessageBox.No):
                 return
-
         mes = Message()
         mes.title = unicode(self.title_edit.text())
         mes.text = unicode(text_post)
         if self.tags:
             mes.tags = unicode(self.tags)
-
+        if self.msg:
+            mes.poster = self.msg.poster
+        #it is draft, it should be deleted before send        
+        if self.msg:
+            self.msg.del_msg_tree()
+        
         from ui.RepeatPost import RepeatPost
         rep_post = RepeatPost(self, mes)
         
@@ -271,7 +277,13 @@ class AddPostWindow(MainWindow):
                                QtGui.QMessageBox.No)
             if (ret == QtGui.QMessageBox.No):
                 return
-
+        
+        #if mes is draft, when remove draft and edit original message
+        id_origin = self.msg.get_option("original") 
+        if id_origin:
+            self.msg.del_msg_tree()
+            self.msg = Message(id_origin)
+              
         mes = self.msg.copy()
         mes.title = unicode(self.title_edit.text())
         mes.text = unicode(text_post)
@@ -284,6 +296,7 @@ class AddPostWindow(MainWindow):
             res = author.edit_post(mes)
         except WarningExc, exc:
             super(AddPostWindow, self).show_warning(exc)
+            self.add_in_draft()
         else:
             ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
                                                 self.tr("Post is edit"),
@@ -389,6 +402,9 @@ class AddPostWindow(MainWindow):
                                      QtGui.QDialogButtonBox.ActionRole)
         self.color_button = but_box.addButton(self.tr("Color"),
                                       QtGui.QDialogButtonBox.ActionRole)
+        self.link_button = but_box2.addButton(self.tr("Link"),
+                                    QtGui.QDialogButtonBox.ActionRole)
+
         cancel_button = self.dial.addButton(QtGui.QMessageBox.Abort)
         cancel_button.hide()
         but_box.adjustSize()
@@ -440,6 +456,8 @@ class AddPostWindow(MainWindow):
                 self.text_edit.insertPlainText("<span style=\"color:#"
                                            + color + "\">"
                                            + link + "</span>")
+        elif button == self.link_button:
+            self.link_post()
         else:
     	    return
         self.dial.reject()
@@ -553,3 +571,44 @@ class AddPostWindow(MainWindow):
         else:
             self.sending_post = True
             super(AddPostWindow, self).home_window()
+
+    def save_post(self):
+        """
+        saving editing post
+        """ 
+        self.add_in_drafts()
+        ret = QtGui.QMessageBox.information(self, self.tr("Scribo"),
+                                                self.tr("Post is edit"),
+                                                QtGui.QMessageBox.Yes)
+        self.sending_post = True
+        from ldm.Message import DRAFT
+        if self.msg and self.msg.type == DRAFT:
+            self.msg.del_msg_tree()
+        super(AddPostWindow, self).home_window()
+        
+    def add_in_drafts(self):
+        """
+        adding current editing post in drafts
+        """
+        if self.combo_view.currentIndex() == 1:
+            text_post =self.plain_text
+        else:
+            text_post = QtCore.QString(unicode(self.text_edit.toPlainText())).trimmed()
+
+        if (text_post == ""):
+            ret = QtGui.QMessageBox.critical(self, self.tr("Scribo"),
+                               self.tr("The post is empty!"),
+                               QtGui.QMessageBox.Ok)
+            return
+        mes = Message()
+        mes.title = unicode(self.title_edit.text())
+        mes.text = unicode(text_post)
+        import time
+        str_date = time.localtime()
+        date = time.strftime(TIME_FORMAT, str_date)
+        mes.date = date
+        if self.tags:
+            mes.tags = unicode(self.tags)
+        if self.msg:
+            mes.poster = self.msg.poster
+            mes.set_option("original",self.msg.id)        
