@@ -35,6 +35,8 @@ class TreeMessage(MainWindow):
         self.parent = parent
         self.centr_widg = QtGui.QWidget(self)
         self.msg = msg
+        self.refresh_all_comments()
+        self.get_msg_comment(msg)
         self.tree_view = self.tree_view_com(msg)
         self.create_actions()
         toolbar = self.create_toolbar()
@@ -101,6 +103,22 @@ class TreeMessage(MainWindow):
         self.tree_view = self.tree_view_com(self.msg)
         self.vbox.addWidget(self.tree_view)
 
+    
+
+    def get_msg_comment(self, msg):
+        list_comments = msg.comments
+        if list_comments:
+            for com in list_comments:
+                print "text = "+com.text+" title = "+ com.title
+                self.get_msg_comment(com)
+        else:
+            return
+
+
+    def refresh_all_comments(self):
+        for acc in main_prof.accounts:
+            acc.refresh_comments()
+
 class MyModel(QtCore.QAbstractItemModel):
     """
     class fill tree of comments
