@@ -81,8 +81,6 @@ class ViewMessage(MainWindow):
             QNetworkProxy.setApplicationProxy(proxy)
 
         self.view_mes_widget = QWebView(self.centr_widg)
-        self.view_mes(msg)
-        self.view_mes_widget.show()
         self.hbox.addWidget(toolbar)
         self.hbox.addSpacing(5)
         self.hbox.addWidget(self.view_mes_widget)
@@ -91,6 +89,9 @@ class ViewMessage(MainWindow):
         self.centr_widg.setLayout(self.hbox)
         self.setCentralWidget(self.centr_widg)
         self.show()
+        self.view_mes(msg)
+        self.view_mes_widget.show()
+
 
     def view_mes(self, msg):
         """ 
@@ -101,6 +102,7 @@ class ViewMessage(MainWindow):
         """
         title = msg.title
         text = msg.text
+        #print "text do tidylib"+text
         user = msg.poster
         date = msg.date
         parent = msg.parent
@@ -122,20 +124,32 @@ class ViewMessage(MainWindow):
         if not msg.read:
             msg.read = True
 
-        import tidylib
-        text = tidylib.tidy_fragment(text)[0]
+        #import tidylib
+        #text = tidylib.tidy_fragment(text)[0]
 
         parent_text = ""
         if parent:
             parent_text = parent.text
         if not parent_text:
             parent_text = ""
-        text = self.text_br(text)
-        css = '<style type="text/css"> .scrib_stl {font: 14pt sans-serif;}\
-         .tags {font: 12pt; color: red; text-decoration:underline} \
-         .date {font-variant:small-caps; color: red;left: -12px;}\
-         .author {font-weight: 600;}</style>'
+        #text = self.text_br(text)
+        #print text
+        header_html = '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">\
+                       <html xmlns="http://www.w3.org/1999/xhtml">\
+                       <head><meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>\
+                       <title>iframe</title>\
+                       <style type="text/css">HTML, BODY { background:transparent; padding:0; margin:0; border:0; overflow:hidden; }\
+                       .scrib_stl {font: 14pt sans-serif;}\
+                       .tags {font: 12pt; color: red; text-decoration:underline}\
+                       .date {font-variant:small-caps; color: red;left: -12px;}\
+                       .author {font-weight: 600;}\
+                       </style></head>'
 
+        code_html =  header_html + '<body style="-moz-user-select: none; -khtml-user-select: none; user-select: none;">'\
+        + '<h3><div class="title">%s</div></h3>' % (title)+'<br/><div class="author">%s</div>' % (author)\
+        + '<div class="date">%s</div>' % (date) + '<br/><div class="scribo_stl"> %s </div>' % (unicode(text))\
+        + '<br/><div class="tags">%s</div></body></html>' % (unicode(tags))
+        #print code_html 
         """
         #version with comment
         self.view_mes_widget.setHtml("<head><meta http-equiv=\"Content-Type\" \
@@ -149,16 +163,7 @@ class ViewMessage(MainWindow):
                     + tags + self.tr("<br/>" "<b> Text:\
                     </b><br />") + text + "<br/>")
         """
-        self.view_mes_widget.setHtml('<head><meta http-equiv="Content-Type" \
-                    content="text/html; charset=utf-8" /> '
-                    + css + '</head><body style=\"-moz-user-select: none; -khtml-user-select: none; user-select: none;\">'
-                    + '<h3><div class="title">%s</div></h3>' % (title)
-                    + '<br/><div class="author">%s</div>' % (author)
-                    + '<div class="date">%s</div>' % (date)
-                    + '<br/><div class="scribo_stl"> %s </div>' % (unicode(text))
-                    + '<br/><div class="tags">\
-                    %s</div></body>' % (unicode(tags)))
-
+        self.view_mes_widget.setHtml(code_html)
         del(title)
         del(text)
         del(user)
@@ -196,6 +201,8 @@ class ViewMessage(MainWindow):
         """
         file_tool_bar = ToolbarWindow(parent=self.centr_widg)
         file_tool_bar.addWidget(self.edit_act)
+        #file_tool_bar.addWidget(self.comment_act)
+        #file_tool_bar.addWidget(self.tree_act)
         self.connect(file_tool_bar.home_act, QtCore.SIGNAL("clicked()"),
                              self.home_window)
 
@@ -260,14 +267,11 @@ class ViewMessage(MainWindow):
         self.incr_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.connect(self.incr_act, QtCore.SIGNAL("clicked()"),
                      self.incr_font)
-
-
-        #don't realized
         """
         self.comment_act = QtGui.QToolButton(self.centr_widg)
         self.comment_act.setIcon(QtGui.QIcon("../data/add_post.png"))
         self.comment_act.setText(self.tr("Write comment"))
-        self.comment_act.setToolButtonStyle(QtCore.Qt.QToolButtonTextUnderIcon)
+        self.comment_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.comment_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.connect(self.comment_act, QtCore.SIGNAL("clicked()"),
                      self.write_comment)
@@ -279,15 +283,15 @@ class ViewMessage(MainWindow):
         self.edit_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.connect(self.edit_act, QtCore.SIGNAL("clicked()"),
                      self.edit_post)
-
+        """
         self.tree_act = QtGui.QToolButton(self.centr_widg)
         #self.tree_act.setIcon(QtGui.QIcon("../data/tree.png"))
-        #self.tree_act.setText(self.tr("Tree of comments"))
+        self.tree_act.setText(self.tr("Tree of comments"))
         self.tree_act.setToolButtonStyle(QtCore.Qt.ToolButtonTextUnderIcon)
         self.tree_act.setSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
         self.connect(self.tree_act, QtCore.SIGNAL("clicked()"),
                      self.tree_comments)
-        
+        """
 
     def view_prev_message(self):
         """
@@ -340,6 +344,7 @@ class ViewMessage(MainWindow):
         @param
         @return                                          
         """
+        comment_widget = AddCommentWindow(parent = self, msg = self.msg)
         pass
 
     def edit_post(self):
@@ -370,7 +375,7 @@ class ViewMessage(MainWindow):
         """
         self.msg.read = True
         self.view_mes(self.msg)
-        self.view_mes_widget.show()
+        self.view_mes_widget.update()
 
     def refresh_mes(self):
         """
@@ -392,4 +397,4 @@ class ViewMessage(MainWindow):
 
 from TreeMessage import *
 from AddPost import *
-
+from AddComment import *
